==> kjy-center-api-0.1.0-dev-lizhi-20190605.063031-11-sources.jar: cn/com/duiba/kjy/api/dto/RocketMqTag.java <==
package cn.com.duiba.kjy.api.dto;


/**
 * Created by dugq on 2019-03-27.
 */
public abstract class RocketMqTag {

    /**
     * 微信支付，兑吧回调
     */
    public static final String TAG_PAY_NOTIFY = "charge";

    /**
     * 客集集VIP公众号微信通知消息
     */
    public static final String TAG_KJJ_VIP_OA_WX_NOTIFY = "TAG_KJJ_VIP_OA_WX_NOTIFY";

    private static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";
    private static final String KJY_SIMPLE_INFORMATION = "KjySimpleInformation";
    private static final String KJY_CONTENT_PUSH_INFORMATION = "KjyContentPushInformation";
    private static final String KJY_CONTENT_GRAB_INFORMATION = "KjyContentGrabInformation";

    private static final String KJY_ACTIVITY_SUBMIT_MESSAGE = "KJY_ACTIVITY_SUBMIT_MESSAGE";

    /**
     * 客集集销售员导入任务
     */
    private static final String KJY_SELLER_IMPORT_MESSAGE = "KjySellerImportMessage";

    public static String getTagNewVisitInformation() {
        return TAG_NEW_VISIT_INFORMATION;
    }

    public static String getKjySimpleInformation() {
        return KJY_SIMPLE_INFORMATION;
    }

    public static String getKjyContentPushInformation() {
        return KJY_CONTENT_PUSH_INFORMATION;
    }

    public static String getKjyContentGrabInformation() {
        return KJY_CONTENT_GRAB_INFORMATION;
    }

    public static String getKjyActivitySubmitMessage() {
        return KJY_ACTIVITY_SUBMIT_MESSAGE;
    }

    public static String getKjySellerImportMessage() {
        return KJY_SELLER_IMPORT_MESSAGE;
    }
}

==> kjy-center-api-0.1.7-dev-lizhi-20190613.103023-2-sources.jar: cn/com/duiba/kjy/api/dto/RocketMqTag.java <==
package cn.com.duiba.kjy.api.dto;


/**
 * Created by dugq on 2019-03-27.
 */
public abstract class RocketMqTag {

    /**
     * 微信支付，兑吧回调
     */
    public static final String TAG_PAY_NOTIFY = "charge";

    /**
     * 晚安问候推送消息
     */
    public static final String TAG_PUSH_EVENING_GREETING = "push_evening_greeting";

    /**
     * 客集集VIP公众号微信通知消息
     */
    public static final String TAG_KJJ_VIP_OA_WX_NOTIFY = "TAG_KJJ_VIP_OA_WX_NOTIFY";

    private static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";
    private static final String KJY_SIMPLE_INFORMATION = "KjySimpleInformation";
    private static final String KJY_CONTENT_PUSH_INFORMATION = "KjyContentPushInformation";
    private static final String KJY_CONTENT_GRAB_INFORMATION = "KjyContentGrabInformation";

    private static final String KJY_ACTIVITY_SUBMIT_MESSAGE = "KJY_ACTIVITY_SUBMIT_MESSAGE";

    private static final String KJY_VIP_UNSUBSCRIBE_MESSAGE = "KJY_VIP_UNSUBSCRIBE_MESSAGE";


    private static final String KJY_CONTENT_PUSH_AFTERNOON = "KJY_CONTENT_PUSH_AFTERNOON";

    public static String getTagNewVisitInformation() {
        return TAG_NEW_VISIT_INFORMATION;
    }

    public static String getKjySimpleInformation() {
        return KJY_SIMPLE_INFORMATION;
    }

    public static String getKjyContentPushInformation() {
        return KJY_CONTENT_PUSH_INFORMATION;
    }

    public static String getKjyContentGrabInformation() {
        return KJY_CONTENT_GRAB_INFORMATION;
    }

    public static String getKjyActivitySubmitMessage() {
        return KJY_ACTIVITY_SUBMIT_MESSAGE;
    }

    public static String getKjyVipUnsubscribeMessage() {
        return KJY_VIP_UNSUBSCRIBE_MESSAGE;
    }

    public static String getKjyContentPushAfternoon() {
        return KJY_CONTENT_PUSH_AFTERNOON;
    }
}
